syaml

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2022 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DeleteBytes

func DeleteBytes(y []byte, path string) ([]byte, error)

DeleteBytes accepts a YAML body and a path, and deletes the specific key in the YAML body matching the path. See https://github.com/tidwall/sjson#examples

func SetBytes

func SetBytes(y []byte, path string, value interface{}) ([]byte, error)

SetBytes accepts a YAML body, a path and a new value, and updates the specific key in the YAML body using the path. See https://github.com/tidwall/sjson#examples

Types

This section is empty.

Jump to